@@ -111,73 +111,73 @@ def service_is_enabled(service_name, strict_check=False):
         return False
 
 
-def service_enable(service_name):
+def service_enable(service_name: str, check: bool = False):
     """Enable and start a service in systemd."""
-    subprocess.call(['systemctl', 'enable', service_name])
-    service_start(service_name)
+    subprocess.run(['systemctl', 'enable', service_name], check=check)
+    service_start(service_name, check=check)
 
 
-def service_disable(service_name):
+def service_disable(service_name: str, check: bool = False):
     """Disable and stop service in systemd."""
-    subprocess.call(['systemctl', 'disable', service_name])
+    subprocess.run(['systemctl', 'disable', service_name], check=check)
     try:
-        service_stop(service_name)
+        service_stop(service_name, check=check)
     except subprocess.CalledProcessError:
         pass
 
 
-def service_mask(service_name):
+def service_mask(service_name: str, check: bool = False):
     """Mask a service"""
-    subprocess.call(['systemctl', 'mask', service_name])
+    subprocess.run(['systemctl', 'mask', service_name], check=check)
 
 
-def service_unmask(service_name):
+def service_unmask(service_name: str, check: bool = False):
     """Unmask a service"""
-    subprocess.call(['systemctl', 'unmask', service_name])
+    subprocess.run(['systemctl', 'unmask', service_name], check=check)
 
 
-def service_start(service_name):
+def service_start(service_name: str, check: bool = False):
     """Start a service with systemd."""
-    service_action(service_name, 'start')
+    service_action(service_name, 'start', check=check)
 
 
-def service_stop(service_name):
+def service_stop(service_name: str, check: bool = False):
     """Stop a service with systemd."""
-    service_action(service_name, 'stop')
+    service_action(service_name, 'stop', check=check)
 
 
-def service_restart(service_name):
+def service_restart(service_name: str, check: bool = False):
     """Restart a service with systemd."""
-    service_action(service_name, 'restart')
+    service_action(service_name, 'restart', check=check)
 
 
-def service_try_restart(service_name):
+def service_try_restart(service_name: str, check: bool = False):
     """Try to restart a service with systemd."""
-    service_action(service_name, 'try-restart')
+    service_action(service_name, 'try-restart', check=check)
 
 
-def service_reload(service_name):
+def service_reload(service_name: str, check: bool = False):
     """Reload a service with systemd."""
-    service_action(service_name, 'reload')
+    service_action(service_name, 'reload', check=check)
 
 
-def service_try_reload_or_restart(service_name):
+def service_try_reload_or_restart(service_name: str, check: bool = False):
     """Reload a service if it supports reloading, otherwise restart.
 
     Do nothing if service is not running.
     """
-    service_action(service_name, 'try-reload-or-restart')
+    service_action(service_name, 'try-reload-or-restart', check=check)
 
 
-def service_reset_failed(service_name):
+def service_reset_failed(service_name: str, check: bool = False):
     """Reset the 'failed' state of units."""
-    service_action(service_name, 'reset-failed')
+    service_action(service_name, 'reset-failed', check=check)
 
 
-def service_action(service_name, action):
+def service_action(service_name: str, action: str, check: bool = False):
     """Perform the given action on the service_name."""
     subprocess.run(['systemctl', action, service_name],
-                   stdout=subprocess.DEVNULL, check=False)
+                   stdout=subprocess.DEVNULL, check=check)
 
 
 def webserver_is_enabled(name, kind='config'):
@@ -449,12 +449,15 @@ def is_disk_image():
     return os.path.exists('/var/lib/freedombox/is-freedombox-disk-image')
 
 
-def run_apt_command(arguments, stdout=subprocess.DEVNULL):
+def run_apt_command(arguments, stdout=subprocess.DEVNULL,
+                    enable_triggers: bool = False):
     """Run apt-get with provided arguments."""
     command = ['apt-get', '--assume-yes', '--quiet=2'] + arguments
 
     env = os.environ.copy()
     env['DEBIAN_FRONTEND'] = 'noninteractive'
+    if not enable_triggers:
+        env['FREEDOMBOX_INVOKED'] = 'true'
     process = subprocess.run(command, stdin=subprocess.DEVNULL, stdout=stdout,
                              env=env, check=False)
     return process.returncode
@@ -535,7 +538,8 @@ def is_package_manager_busy():
 def podman_create(container_name: str, image_name: str, volume_name: str,
                   volume_path: str, volumes: dict[str, str] | None = None,
                   env: dict[str, str] | None = None,
-                  binds_to: list[str] | None = None):
+                  binds_to: list[str] | None = None,
+                  devices: dict[str, str] | None = None):
     """Remove and recreate a podman container."""
     service_stop(f'{volume_name}-volume.service')
     service_stop(container_name)
@@ -570,6 +574,9 @@ Options=bind
         [f'Environment={key}={value}' for key, value in (env or {}).items()])
     bind_lines = '\n'.join(f'BindsTo={service}\nAfter={service}'
                            for service in (binds_to or []))
+    devices_lines = '\n'.join(f'AddDevice={source}:{dest}'
+                              for source, dest in (devices or {}).items()
+                              if pathlib.Path(source).exists())
     contents = f'''[Unit]
 Requires={volume_name}-volume.service
 After={volume_name}-volume.service
@@ -582,6 +589,7 @@ ContainerName=%N
 Image={image_name}
 Network=host
 {volume_lines}
+{devices_lines}
 
 [Service]
 Restart=always
@@ -595,16 +603,16 @@ WantedBy=default.target
     # Re-running setup should be sufficient.
     _podman_create_fallback_service_file(container_name, image_name,
                                          volume_name, volume_path, volumes,
-                                         env, binds_to)
+                                         env, binds_to, devices)
 
     service_daemon_reload()
 
 
-def _podman_create_fallback_service_file(container_name: str, image_name: str,
-                                         volume_name: str, volume_path: str,
-                                         volumes: dict[str, str] | None = None,
-                                         env: dict[str, str] | None = None,
-                                         binds_to: list[str] | None = None):
+def _podman_create_fallback_service_file(
+        container_name: str, image_name: str, volume_name: str,
+        volume_path: str, volumes: dict[str, str] | None = None,
+        env: dict[str, str] | None = None, binds_to: list[str] | None = None,
+        devices: dict[str, str] | None = None):
     """Create a systemd unit file if systemd generator is not available."""
     service_file = pathlib.Path(
         f'/etc/systemd/system/{container_name}.service')
@@ -627,6 +635,10 @@ def _podman_create_fallback_service_file(container_name: str, image_name: str,
     volume_args = ' '.join(
         (f'-v {host_path}:{container_path}'
          for host_path, container_path in (volumes or {}).items()))
+    devices_args = ' '.join(
+        (f'-d {host_path}:{container_path}'
+         for host_path, container_path in (devices or {}).items()
+         if pathlib.Path(host_path).exists()))
 
     # Similar to the file quadlet systemd generator produces but with volume
     # related commands merged.
@@ -648,7 +660,7 @@ SyslogIdentifier=%N
 ExecStartPre=/usr/bin/rm -f %t/%N.cid
 ExecStartPre=/usr/bin/podman volume rm --force {volume_name}
 ExecStartPre=/usr/bin/podman volume create --driver=local --opt device={volume_path} --opt o=bind {volume_name}
-ExecStart=/usr/bin/podman run --name=%N --cidfile=%t/%N.cid --replace --rm --cgroups=split --network=host --sdnotify=conmon --detach --label io.containers.autoupdate=registry {volume_args} {env_args} {image_name}
+ExecStart=/usr/bin/podman run --name=%N --cidfile=%t/%N.cid --replace --rm --cgroups=split --network=host --sdnotify=conmon --detach --label io.containers.autoupdate=registry {volume_args} {env_args} {devices_args} {image_name}
 
 [Install]
 WantedBy=default.target
