@@ -6,6 +6,7 @@ pytest configuration for all tests.
 import importlib
 import os
 import pathlib
+from unittest.mock import patch
 
 import pytest
 
@@ -17,9 +18,9 @@ except ImportError:
     _functional_libs_available = False
 
 
-def pytest_ignore_collect(path, config):
+def pytest_ignore_collect(collection_path, config):
     """Ignore functional tests when splinter is not available."""
-    if path.basename == 'test_functional.py':
+    if collection_path.name == 'test_functional.py':
         return not _functional_libs_available
 
 
@@ -109,6 +110,17 @@ def fixture_needs_sudo():
         pytest.skip('Needs sudo command installed.')
 
 
+@pytest.fixture(name='no_privileged_server', scope='module')
+def fixture_no_privileged__server():
+    """Don't setup for and run privileged methods on server.
+
+    Tests on using privileged daemon are not yet implemented.
+    """
+    with patch('plinth.actions._run_privileged_method_on_server') as mock:
+        mock.side_effect = NotImplementedError
+        yield
+
+
 @pytest.fixture(scope='session')
 def splinter_selenium_implicit_wait():
     """Disable implicit waiting."""
