@@ -15,7 +15,8 @@ from plinth.modules.backups import privileged
 from plinth.modules.backups.repository import BorgRepository, SshBorgRepository
 from plinth.tests import config as test_config
 
-pytestmark = pytest.mark.usefixtures('needs_root', 'needs_borg', 'load_cfg')
+pytestmark = pytest.mark.usefixtures('needs_root', 'needs_borg', 'load_cfg',
+                                     'no_privileged_server')
 
 # try to access a non-existing url and a URL that exists but does not
 # grant access
