@@ -18,6 +18,7 @@ from plinth.diagnostic_check import (DiagnosticCheck,
 from plinth.errors import MissingPackageError
 from plinth.utils import format_lazy
 
+from . import kvstore
 from . import operation as operation_module
 from .errors import PackageNotInstalledError
 
@@ -113,7 +114,8 @@ class Packages(app_module.FollowerComponent):
                  packages: list[str | PackageExpression],
                  skip_recommends: bool = False,
                  conflicts: list[str] | None = None,
-                 conflicts_action: ConflictsAction | None = None):
+                 conflicts_action: ConflictsAction | None = None,
+                 rerun_setup_on_upgrade: bool = False):
         """Initialize a new packages component.
 
         'component_id' should be a unique ID across all components of an app
@@ -131,6 +133,10 @@ class Packages(app_module.FollowerComponent):
         'conflicts_action' is a string representing the action to take when it
         is found that conflicting Debian packages are installed on the system.
         None if there are no known conflicting packages.
+
+        'rerun_setup_on_upgrade' is a boolean to specify whether app's setup
+        process should be rerun if a .deb package is upgraded (by someone other
+        than FreedomBox process).
         """
         super().__init__(component_id)
 
@@ -145,6 +151,7 @@ class Packages(app_module.FollowerComponent):
         self.skip_recommends = skip_recommends
         self.conflicts = conflicts or []
         self.conflicts_action = conflicts_action
+        self.rerun_setup_on_upgrade = rerun_setup_on_upgrade
 
     @property
     def package_expressions(self) -> list[PackageExpression]:
@@ -187,8 +194,11 @@ class Packages(app_module.FollowerComponent):
         # Ensure package list is update-to-date before looking at dependencies.
         refresh_package_lists()
 
-        # List of packages to purge from the system
-        packages = self.get_actual_packages()
+        # List of packages to purge from the system. Be resilient to a package
+        # not being found in apt's cache by not using get_actual_packages(). If
+        # a package expression is listed as (package1 | package2) then try to
+        # remove both packages.
+        packages = self.possible_packages
         logger.info('App\'s list of packages to remove: %s', packages)
 
         packages = self._filter_packages_to_keep(packages)
@@ -242,27 +252,38 @@ class Packages(app_module.FollowerComponent):
 
         return packages_installed(self.conflicts)
 
-    def has_unavailable_packages(self) -> bool | None:
-        """Return whether any of the packages are not available.
+    def is_available(self) -> bool:
+        """Return whether all of the packages are available.
 
-        Returns True if one or more of the packages is not available in the
-        user's Debian distribution or False otherwise. Returns None if it
-        cannot be reliably determined whether the packages are available or
-        not.
+        Returns True if all of the packages are available in the user's Debian
+        distribution or False otherwise. Returns True if it cannot be reliably
+        determined whether the packages are available or not.
+
+        This operation can run for a long time as package cache may be
+        refreshed.
         """
-        apt_lists_dir = pathlib.Path('/var/lib/apt/lists/')
-        num_files = len(
-            [child for child in apt_lists_dir.iterdir() if child.is_file()])
-        if num_files < 2:  # not counting the lock file
-            return None
+        try:
+            self.get_actual_packages()
+            return True  # All packages were found in the cache
+        except MissingPackageError:
+            pass  # We will retry after refreshing package list
 
-        # List of all packages from all Package components
+        # If the package cache is new, then package is really not available.
+        package_cache = pathlib.Path('/var/cache/apt/pkgcache.bin')
+        if (package_cache.exists()
+                and time.time() - package_cache.stat().st_mtime < 3600):
+            return False
+
+        # Perform 'apt-get update'
+        refresh_package_lists()
+
+        # Check again for all the packages
         try:
             self.get_actual_packages()
         except MissingPackageError:
-            return True
+            return False
 
-        return False
+        return True
 
     def _filter_packages_to_keep(self, packages: list[str]) -> list[str]:
         """Filter out the list of packages to keep from given list.
@@ -286,7 +307,7 @@ class Packages(app_module.FollowerComponent):
 
             # Remove packages used by other installed apps
             for component in app.get_components_of_type(Packages):
-                keep_packages |= set(component.get_actual_packages())
+                keep_packages |= set(component.possible_packages)
 
         # Get list of all the dependencies of packages to keep.
         keep_packages_with_deps: set[str] = set()
@@ -463,6 +484,7 @@ def install(package_names, skip_recommends=False, force_configuration=None,
     operation.thread_data['transaction'] = transaction
     transaction.install(skip_recommends, force_configuration, reinstall,
                         force_missing_configuration)
+    mark_known(package_names)
 
 
 def uninstall(package_names, purge):
@@ -487,6 +509,7 @@ def uninstall(package_names, purge):
     transaction = package.Transaction(operation.app_id, package_names)
     operation.thread_data['transaction'] = transaction
     transaction.uninstall(purge)
+    unmark_known(package_names)
 
 
 def is_package_manager_busy():
@@ -529,3 +552,49 @@ def packages_installed(candidates: list | tuple) -> list:
             pass
 
     return installed_packages
+
+
+def get_known() -> dict[str, dict]:
+    """Return all the known packages and their versions.
+
+    If a package is not known or has a version lower than the currently
+    installed version, it means that the package has been installe or updated
+    outside of FreedomBox. Some app, may use this information to rerun the
+    setup on the app so that configuration is updated.
+    """
+    return kvstore.get_default('packages_known', {})
+
+
+def mark_known(packages: list[str]):
+    """Mark a given list of packages as known."""
+    packages_known = get_known()
+    cache = apt.Cache()
+    for package_ in packages:
+        try:
+            cache_package = cache[package_]
+        except KeyError:
+            logger.warn('Package %s is not found when marking known', package_)
+            continue
+
+        if not cache_package.installed:
+            logger.warn('Package %s is not installed when marking known',
+                        package_)
+            continue
+
+        installed_version = cache_package.installed.version
+        package_known = packages_known.setdefault(package_, {})
+        package_known['version'] = installed_version
+
+    kvstore.set('packages_known', packages_known)
+
+
+def unmark_known(packages: list[str]):
+    """Mark a give list of packages unknown."""
+    packages_known = get_known()
+    for package_ in packages:
+        try:
+            packages_known.pop(package_)
+        except KeyError:
+            pass
+
+    kvstore.set('packages_known', packages_known)
